@@ -1,5 +1,6 @@
 #!python3
 
+### Exceptions ###
 class Error(Exception):
     pass
 
@@ -20,3 +21,9 @@ class UITypeError(TypeError):
 
 class UIValueError(ValueError):
     pass
+
+### Warnings ###
+import warnings
+
+class DatafileImportWarning(Warning):
+    pass
