@@ -412,7 +412,7 @@ class XExpOfHGedney071720:
 
         return hysteresisBundle
 
-class XExpGendey101620:
+class XExpGedney101620:
     def __init__(self, xInit:np.float64, mSat:np.float64, mNuc:np.float64, hCoercive:np.float64, hAnh:np.float64, hCoop:np.float64):
         self.xInit = xInit
         self.mSat = mSat
@@ -421,6 +421,9 @@ class XExpGendey101620:
         self.hAnh = hAnh
         self.hCoop = hCoop
 
+    def evaluate(mSignal:Signal, mRev:np.float64, hRev:np.float64, curveRegion:str):
+        pass
+        
     def evaluate(self, mSignal:Signal, mRev:np.float64, hRev:np.float64, curveRegion:str):
         # Calculate intermediate expressions
         m = np.divide(mSignal.independentThread.data, self.mSat)
